@@ -8,7 +8,8 @@
 'use strict';
 
 require('mocha');
-var os = require('os');
+var path = require('path');
+var homedir = require('homedir-polyfill');
 var assert = require('assert');
 var gm = require('global-modules');
 var resolve = require('./');
@@ -19,12 +20,12 @@ describe('resolve', function() {
   });
 
   it('should resolve the path to user home:', function() {
-    assert.equal(resolve('~'), os.homedir());
-    assert.equal(resolve('~/foo'), os.homedir() + '/foo');
+    assert.equal(resolve('~'), homedir());
+    assert.equal(resolve('~/foo'), path.join(homedir(), '/foo'));
   });
 
   it('should resolve the path to global npm modules:', function() {
     assert.equal(resolve('@'), gm);
-    assert.equal(resolve('@/foo'), gm + '/foo');
+    assert.equal(resolve('@/foo'), path.join(gm, '/foo'));
   });
 });
